@@ -6,6 +6,8 @@ test_that("geoms don't throw an error or warning", {
       fill = hdi,
       area = gdp_mil_usd,
       subgroup = econ_classification,
+      subgroup2 = hemisphere,
+      subgroup3 = region,
       label = country
     )) +
       geom_treemap() +
@@ -16,7 +18,23 @@ test_that("geoms don't throw an error or warning", {
         reflow = F
       ) +
       geom_treemap_subgroup_border(linetype = "dashed") +
+      geom_treemap_subgroup2_border(linetype = "dashed") +
+      geom_treemap_subgroup3_border(linetype = "dashed") +
       geom_treemap_subgroup_text(grow = F, place = "bottomleft", size = 10, reflow = T) +
+      geom_treemap_subgroup_text(
+        level = "subgroup2",
+        grow = F,
+        place = "bottomleft",
+        size = 10,
+        reflow = T
+      ) +
+      geom_treemap_subgroup_text(
+        level = "subgroup3",
+        grow = F,
+        place = "bottomleft",
+        size = 10,
+        reflow = T
+      ) +
       ggplot2::facet_grid(econ_classification ~ region) +
       ggplot2::scale_colour_gradient(low = "red", high = "green")
   } , NA)
